What is cfblog?
===============

It is a blog engine with a peculiar CMS feature, that allows very complex
content to be easily created.

Installation
============

.. code:: bash

    $ pip install cfblog


Contributors
============

* Amit Upadhyay (https://github.com/amitu)
* Vinay Karanam (https://github.com/vinayinvicible)

ChangeLog
=========

https://github.com/Coverfox/cfblog/blob/master/ChangeLog.rst


LICENSE
=======

* BSD
